@@ -1,6 +1,7 @@
 #' Open the datasets directory
 #'
-#' This function will open the directory which contains the dataset files.
+#' This function will open the directory which contains the local datasets files 
+#' used in polygot thanks to the pins package.
 #'
 #' @details
 #' This function opens the directory which contain all the dataset files which are
@@ -13,9 +14,12 @@
 #' learn_dir()
 #' }
 #'
+#' @importFrom pins board_local_storage
+#'
 #' @export
 
-learn_dir <- function(polyglotDirectory = paste0("", system.file("extdata/", package = "polyglot"), "")){
+learn_dir <- function(polyglotDirectory = pins::board_local_storage()){
+  
   if (.Platform['OS.type'] == "windows"){
     shell.exec(polyglotDirectory)
   } else {
